@@ -225,8 +225,10 @@ class Circuit:
             matrix = gates.bmatrix(matrix)
             doc = """
             Apply **%s** gate on the circuit.
+            See :py:meth:`tensorcircuit.gates.%s_gate`.
 
-            :param index: Qubit number than the gate applies on.
+
+            :param index: Qubit number that the gate applies on.
                 The matrix for the gate is
 
                 .. math::
@@ -236,12 +238,13 @@ class Circuit:
             :type index: int.
             """ % (
                 g.upper(),
+                g,
                 matrix,
             )
             docs = """
             Apply **%s** gate on the circuit.
 
-            :param index: Qubit number than the gate applies on.
+            :param index: Qubit number that the gate applies on.
             :type index: int.
             """ % (
                 g.upper()
@@ -271,13 +274,16 @@ class Circuit:
             )
             doc = """
             Apply **%s** gate with parameters on the circuit.
+            See :py:meth:`tensorcircuit.gates.%s_gate`.
 
-            :param index: Qubit number than the gate applies on.
+
+            :param index: Qubit number that the gate applies on.
             :type index: int.
             :param vars: Parameters for the gate.
             :type vars: float.
             """ % (
-                g.upper()
+                g.upper(),
+                g,
             )
             getattr(cls, g).__doc__ = doc
             getattr(cls, g.upper()).__doc__ = doc
@@ -300,7 +306,7 @@ class Circuit:
             doc = """
             Apply %s gate in MPO format on the circuit.
 
-            :param index: Qubit number than the gate applies on.
+            :param index: Qubit number that the gate applies on.
             :type index: int.
             :param vars: Parameters for the gate.
             :type vars: float.
@@ -309,6 +315,7 @@ class Circuit:
             )
             getattr(cls, g).__doc__ = doc
             getattr(cls, g.upper()).__doc__ = doc
+
         for gate_alias in cls.gate_alias_list:
             present_gate = gate_alias[0]
             for alias_gate in gate_alias[1:]:
@@ -693,7 +700,7 @@ class Circuit:
         """
         self._apply_qir(self, qir)
 
-    def mid_measurement(self, index: int, keep: int = 0) -> None:
+    def mid_measurement(self, index: int, keep: int = 0) -> Tensor:
         """
         Middle measurement in z-basis on the circuit, note the wavefunction output is not normalized
         with ``mid_measurement`` involved, one should normalize the state manually if needed.
@@ -705,8 +712,8 @@ class Circuit:
         :type keep: int, optional
         """
         # normalization not guaranteed
-        assert keep in [0, 1]
-        if keep == 0:
+        # assert keep in [0, 1]
+        if keep < 0.5:
             gate = np.array(
                 [
                     [1.0],
@@ -730,6 +737,9 @@ class Circuit:
         self._front[index] = mg2.get_edge(0)
         self._nodes.append(mg1)
         self._nodes.append(mg2)
+        r = backend.convert_to_tensor(keep)
+        r = backend.cast(r, "int32")
+        return r
 
     mid_measure = mid_measurement
     post_select = mid_measurement
@@ -912,6 +922,7 @@ class Circuit:
     ) -> Tensor:
         """
         Apply unitary gates in ``kraus`` randomly based on corresponding ``prob``.
+        If ``prob`` is ``None``, this is reduced to kraus channel language.
 
         :param kraus: List of ``tc.gates.Gate`` or just Tensors
         :type kraus: Sequence[Gate]
@@ -1257,7 +1268,9 @@ class Circuit:
         no.extend(ms)
         return contractor(no).tensor
 
-    def measure(self, *index: int, with_prob: bool = False) -> Tuple[str, float]:
+    def measure_reference(
+        self, *index: int, with_prob: bool = False
+    ) -> Tuple[str, float]:
         """
         Take measurement on the given quantum lines by ``index``.
 
@@ -1371,6 +1384,8 @@ class Circuit:
         else:
             return sample, -1.0
 
+    measure = measure_jit
+
     def perfect_sampling(self) -> Tuple[str, float]:
         """
         Sampling bistrings from the circuit output based on quantum amplitudes.
@@ -1453,40 +1468,6 @@ class Circuit:
         nodes1 = self.expectation_before(*ops, reuse=reuse)
         return contractor(nodes1).tensor
 
-    def expectation_ps(
-        self,
-        x: Optional[Sequence[int]] = None,
-        y: Optional[Sequence[int]] = None,
-        z: Optional[Sequence[int]] = None,
-        reuse: bool = True,
-    ) -> Tensor:
-        """
-        Shortcut for Pauli string expectation.
-        x, y, z list are for X, Y, Z positions
-
-        :param x: _description_, defaults to None
-        :type x: Optional[Sequence[int]], optional
-        :param y: _description_, defaults to None
-        :type y: Optional[Sequence[int]], optional
-        :param z: _description_, defaults to None
-        :type z: Optional[Sequence[int]], optional
-        :param reuse: whether to cache and reuse the wavefunction, defaults to True
-        :type reuse: bool, optional
-        :return: Expectation value
-        :rtype: Tensor
-        """
-        obs = []
-        if x is not None:
-            for i in x:
-                obs.append([gates.x(), [i]])  # type: ignore
-        if y is not None:
-            for i in y:
-                obs.append([gates.y(), [i]])  # type: ignore
-        if z is not None:
-            for i in z:
-                obs.append([gates.z(), [i]])  # type: ignore
-        return self.expectation(*obs, reuse=reuse)  # type: ignore
-
     def to_qiskit(self) -> Any:
         """
         Translate ``tc.Circuit`` to a qiskit QuantumCircuit object.
@@ -1570,7 +1551,51 @@ class Circuit:
     tex = vis_tex
 
 
+def _expectation_ps(
+    c: Circuit,
+    x: Optional[Sequence[int]] = None,
+    y: Optional[Sequence[int]] = None,
+    z: Optional[Sequence[int]] = None,
+    reuse: bool = True,
+) -> Tensor:
+    """
+    Shortcut for Pauli string expectation.
+    x, y, z list are for X, Y, Z positions
+
+    :Example:
+
+    >>> c = tc.Circuit(2)
+    >>> c.X(0)
+    >>> c.H(1)
+    >>> c.expectation_ps(x=[1], z=[0])
+    array(-0.99999994+0.j, dtype=complex64)
+
+    :param x: _description_, defaults to None
+    :type x: Optional[Sequence[int]], optional
+    :param y: _description_, defaults to None
+    :type y: Optional[Sequence[int]], optional
+    :param z: _description_, defaults to None
+    :type z: Optional[Sequence[int]], optional
+    :param reuse: whether to cache and reuse the wavefunction, defaults to True
+    :type reuse: bool, optional
+    :return: Expectation value
+    :rtype: Tensor
+    """
+    obs = []
+    if x is not None:
+        for i in x:
+            obs.append([gates.x(), [i]])  # type: ignore
+    if y is not None:
+        for i in y:
+            obs.append([gates.y(), [i]])  # type: ignore
+    if z is not None:
+        for i in z:
+            obs.append([gates.z(), [i]])  # type: ignore
+    return c.expectation(*obs, reuse=reuse)  # type: ignore
+
+
 Circuit._meta_apply()
+Circuit.expectation_ps = _expectation_ps  # type: ignore
 
 
 def to_graphviz(
