@@ -12,7 +12,7 @@ import tensornetwork as tn
 
 from . import gates
 from . import channels
-from .circuit import Circuit
+from .circuit import Circuit, _expectation_ps
 from .cons import backend, contractor, npdtype, dtypestr
 
 Gate = gates.Gate
@@ -27,6 +27,18 @@ class DMCircuit:
         inputs: Optional[Tensor] = None,
         dminputs: Optional[Tensor] = None,
     ) -> None:
+        """
+        The density matrix simulator based on tensornetwork engine.
+
+        :param nqubits: Number of qubits
+        :type nqubits: int
+        :param empty: if True, nothing initialized, only for internal use, defaults to False
+        :type empty: bool, optional
+        :param inputs: the state input for the circuit, defaults to None
+        :type inputs: Optional[Tensor], optional
+        :param dminputs: the density matrix input for the circuit, defaults to None
+        :type dminputs: Optional[Tensor], optional
+        """
         if not empty:
             _prefix = "qb-"
             if (inputs is None) and (dminputs is None):
@@ -85,6 +97,8 @@ class DMCircuit:
                 g.upper(),
                 cls.apply_general_gate_delayed(getattr(gates, g), name=g),
             )
+            getattr(cls, g).__doc__ = getattr(Circuit, g).__doc__
+            getattr(cls, g.upper()).__doc__ = getattr(Circuit, g).__doc__
 
         for g in Circuit.vgates:
             setattr(
@@ -97,6 +111,8 @@ class DMCircuit:
                 g.upper(),
                 cls.apply_general_variable_gate_delayed(getattr(gates, g), name=g),
             )
+            getattr(cls, g).__doc__ = getattr(Circuit, g).__doc__
+            getattr(cls, g.upper()).__doc__ = getattr(Circuit, g).__doc__
 
         for k in channels.channels:
             setattr(
@@ -104,6 +120,24 @@ class DMCircuit:
                 k,
                 cls.apply_general_kraus_delayed(getattr(channels, k + "channel")),
             )
+            doc = """
+            Apply %s quantum channel on the circuit.
+            See :py:meth:`tensorcircuit.channels.%schannel`
+
+            :param index: Qubit number that the gate applies on.
+            :type index: int.
+            :param vars: Parameters for the channel.
+            :type vars: float.
+            """ % (
+                k,
+                k,
+            )
+            getattr(cls, k).__doc__ = doc
+
+        for gate_alias in Circuit.gate_alias_list:
+            present_gate = gate_alias[0]
+            for alias_gate in gate_alias[1:]:
+                setattr(cls, alias_gate, getattr(cls, present_gate))
 
     def _copy(
         self,
@@ -239,7 +273,17 @@ class DMCircuit:
 
         return apply
 
-    def densitymatrix(self, check: bool = False, reuse: bool = True) -> tn.Node.tensor:
+    def densitymatrix(self, check: bool = False, reuse: bool = True) -> Tensor:
+        """
+        Return the output density matrix of the circuit.
+
+        :param check: check whether the final return is a legal density matrix, defaults to False
+        :type check: bool, optional
+        :param reuse: whether to reuse previous results, defaults to True
+        :type reuse: bool, optional
+        :return: The output densitymatrix in 2D shape tensor form
+        :rtype: Tensor
+        """
         nodes, _ = self._copy_dm_tensor(conj=False, reuse=reuse)
         # t = contractor(nodes, output_edge_order=d_edges)
         dm = backend.reshape(
@@ -251,7 +295,19 @@ class DMCircuit:
 
     state = densitymatrix
 
-    def expectation(self, *ops: Tuple[tn.Node, List[int]]) -> tn.Node.tensor:
+    def expectation(
+        self, *ops: Tuple[tn.Node, List[int]], **kws: Any
+    ) -> tn.Node.tensor:
+        """
+        Compute the expectation of corresponding operators.
+
+        :param ops: Operator and its position on the circuit,
+            eg. ``(tc.gates.z(), [1, ]), (tc.gates.x(), [2, ])`` is for operator :math:`Z_1X_2`.
+        :type ops: Tuple[tn.Node, List[int]]
+        :return: Tensor with one element
+        :rtype: Tensor
+        """
+        # kws is reserved for unsupported feature such as reuse arg
         newdm, newdang = self._copy(self._nodes, self._rfront + self._lfront)
         occupied = set()
         nodes = newdm
@@ -341,39 +397,6 @@ class DMCircuit:
 
     sample = perfect_sampling
 
-    def expectation_ps(
-        self,
-        x: Optional[Sequence[int]] = None,
-        y: Optional[Sequence[int]] = None,
-        z: Optional[Sequence[int]] = None,
-        reuse: bool = True,
-    ) -> Tensor:
-        """
-        Shortcut for Pauli string expectation.
-        x, y, z list are for X, Y, Z positions
-
-        :param x: _description_, defaults to None
-        :type x: Optional[Sequence[int]], optional
-        :param y: _description_, defaults to None
-        :type y: Optional[Sequence[int]], optional
-        :param z: _description_, defaults to None
-        :type z: Optional[Sequence[int]], optional
-        :param reuse: whether to cache and reuse the wavefunction, defaults to True
-        :type reuse: bool, optional
-        :return: Expectation value
-        :rtype: Tensor
-        """
-        obs = []
-        if x is not None:
-            for i in x:
-                obs.append([gates.x(), [i]])  # type: ignore
-        if y is not None:
-            for i in y:
-                obs.append([gates.y(), [i]])  # type: ignore
-        if z is not None:
-            for i in z:
-                obs.append([gates.z(), [i]])  # type: ignore
-        return self.expectation(*obs)  # type: ignore
-
 
 DMCircuit._meta_apply()
+DMCircuit.expectation_ps = _expectation_ps  # type: ignore
